@@ -45,6 +45,7 @@ class PMA_Tracker_Test extends PHPUnit_Framework_TestCase
         $GLOBALS['cfg']['DBG']['sql'] = false;
 
         $_SESSION['relation'][$GLOBALS['server']] = array(
+            'PMA_VERSION' => PMA_VERSION,
             'db' => 'pmadb',
             'tracking' => 'tracking'
         );
@@ -107,6 +108,7 @@ class PMA_Tracker_Test extends PHPUnit_Framework_TestCase
         PMA_Tracker::enable();
 
         $_SESSION['relation'][$GLOBALS['server']] = array(
+            'PMA_VERSION' => PMA_VERSION,
             'trackingwork' => false
         );
 
@@ -115,6 +117,7 @@ class PMA_Tracker_Test extends PHPUnit_Framework_TestCase
         );
 
         $_SESSION['relation'][$GLOBALS['server']] = array(
+            'PMA_VERSION' => PMA_VERSION,
             'trackingwork' => true,
             'db' => 'pmadb',
             'tracking' => 'tracking'
@@ -180,6 +183,7 @@ class PMA_Tracker_Test extends PHPUnit_Framework_TestCase
 
         PMA_Tracker::enable();
 
+        $_SESSION['relation'][$GLOBALS['server']]['PMA_VERSION'] = PMA_VERSION;
         $_SESSION['relation'][$GLOBALS['server']]['trackingwork'] = false;
 
         $this->assertFalse(
@@ -552,7 +556,7 @@ class PMA_Tracker_Test extends PHPUnit_Framework_TestCase
         $GLOBALS['dbi'] = $dbi;
 
         $this->assertEquals(
-            'executed_1',
+            true,
             PMA_Tracker::changeTrackingData(
                 'pma_db',
                 'pma_table',
@@ -563,7 +567,7 @@ class PMA_Tracker_Test extends PHPUnit_Framework_TestCase
         );
 
         $this->assertEquals(
-            'executed_2',
+            true,
             PMA_Tracker::changeTrackingData(
                 'pma_db',
                 'pma_table',
@@ -613,8 +617,8 @@ class PMA_Tracker_Test extends PHPUnit_Framework_TestCase
         runkit_constant_redefine("PMA_DRIZZLE", true);
 
         $sql_query = " SELECT MAX(version) FROM `pmadb`.`tracking`" .
-        " WHERE `db_name` = 'pma''db' " .
-        " AND `table_name` = 'pma''table' ";
+        " WHERE `db_name` = 'pma\\'db' " .
+        " AND `table_name` = 'pma\\'table' ";
 
         $sql_query_drizzle = ' AND tracking & 1 <> 0';
 
@@ -675,8 +679,8 @@ class PMA_Tracker_Test extends PHPUnit_Framework_TestCase
     public function testGetTrackedData($fetchArrayReturn, $expectedArray)
     {
         $sql_query = " SELECT * FROM `pmadb`.`tracking`" .
-            " WHERE `db_name` = 'pma''db' " .
-            " AND `table_name` = 'pma''table' " .
+            " WHERE `db_name` = 'pma\\'db' " .
+            " AND `table_name` = 'pma\\'table' " .
             " AND `version` = '1.0' " .
             " ORDER BY `version` DESC LIMIT 1";
 
@@ -1012,4 +1016,3 @@ class PMA_Tracker_Test extends PHPUnit_Framework_TestCase
         );
     }
 }
-?>
