@@ -11,7 +11,6 @@
  * Include to test.
  */
 require_once 'libraries/Util.class.php';
-require_once 'libraries/sqlparser.data.php';
 
 /**
  * Test for quoting, slashing/backslashing
@@ -36,7 +35,7 @@ class PMA_QuotingSlashing_Test extends PHPUnit_Framework_TestCase
             PMA_Util::sqlAddSlashes($string, true, true, true)
         );
         $this->assertEquals(
-            "\\\\\\\\''test''''\\\\\\\\''''\\\\\\\\''\\r\\t\\n",
+            "\\\\\\\\\\'test\\'\\'\\\\\\\\\\'\\'\\\\\\\\\\'\\r\\t\\n",
             PMA_Util::sqlAddSlashes($string, true, true, false)
         );
         $this->assertEquals(
@@ -44,7 +43,7 @@ class PMA_QuotingSlashing_Test extends PHPUnit_Framework_TestCase
             PMA_Util::sqlAddSlashes($string, true, false, true)
         );
         $this->assertEquals(
-            "\\\\\\\\''test''''\\\\\\\\''''\\\\\\\\''\r\t\n",
+            "\\\\\\\\\\'test\\'\\'\\\\\\\\\\'\\'\\\\\\\\\\'\r\t\n",
             PMA_Util::sqlAddSlashes($string, true, false, false)
         );
         $this->assertEquals(
@@ -52,7 +51,7 @@ class PMA_QuotingSlashing_Test extends PHPUnit_Framework_TestCase
             PMA_Util::sqlAddSlashes($string, false, true, true)
         );
         $this->assertEquals(
-            "\\\\''test''''\\\\''''\\\\''\\r\\t\\n",
+            "\\\\\\'test\\'\\'\\\\\\'\\'\\\\\\'\\r\\t\\n",
             PMA_Util::sqlAddSlashes($string, false, true, false)
         );
         $this->assertEquals(
@@ -60,9 +59,13 @@ class PMA_QuotingSlashing_Test extends PHPUnit_Framework_TestCase
             PMA_Util::sqlAddSlashes($string, false, false, true)
         );
         $this->assertEquals(
-            "\\\\''test''''\\\\''''\\\\''\r\t\n",
+            "\\\\\\'test\\'\\'\\\\\\'\\'\\\\\\'\r\t\n",
             PMA_Util::sqlAddSlashes($string, false, false, false)
         );
+        $this->assertEquals(
+            "\\\\\\'",
+            PMA_Util::sqlAddSlashes('\\\'')
+        );
     }
 
     /**
@@ -214,14 +217,18 @@ class PMA_QuotingSlashing_Test extends PHPUnit_Framework_TestCase
      */
     public function testBackquoteForbidenWords()
     {
-        global $PMA_SQPdata_forbidden_word;
-
-        foreach ($PMA_SQPdata_forbidden_word as $forbidden) {
-            $this->assertEquals(
-                "`" . $forbidden . "`",
-                PMA_Util::backquote($forbidden, false)
-            );
+        foreach (SqlParser\Context::$KEYWORDS as $keyword => $type) {
+            if ($type & SqlParser\Token::FLAG_KEYWORD_RESERVED) {
+                $this->assertEquals(
+                    "`" . $keyword . "`",
+                    PMA_Util::backquote($keyword, false)
+                );
+            } else {
+                $this->assertEquals(
+                    $keyword,
+                    PMA_Util::backquote($keyword, false)
+                );
+            }
         }
     }
 }
-?>
