@@ -11,8 +11,18 @@
  */
 require_once 'libraries/core.lib.php';
 
-class PMA_ifSetOr_test extends PHPUnit_Framework_TestCase
+/**
+ * Tests for PMA_ifSetOr() from libraries/core.lib.php
+ *
+ * @package PhpMyAdmin-test
+ */
+class PMA_IfSetOr_Test extends PHPUnit_Framework_TestCase
 {
+    /**
+     * Test for PMA_ifSetOr
+     *
+     * @return void
+     */
     public function testVarSet()
     {
         $default = 'foo';
@@ -20,6 +30,12 @@ class PMA_ifSetOr_test extends PHPUnit_Framework_TestCase
         $out = PMA_ifSetOr($in, $default);
         $this->assertEquals($in, $out);
     }
+
+    /**
+     * Test for PMA_ifSetOr
+     *
+     * @return void
+     */
     public function testVarSetWrongType()
     {
         $default = 'foo';
@@ -27,6 +43,12 @@ class PMA_ifSetOr_test extends PHPUnit_Framework_TestCase
         $out = PMA_ifSetOr($in, $default, 'boolean');
         $this->assertEquals($out, $default);
     }
+
+    /**
+     * Test for PMA_ifSetOr
+     *
+     * @return void
+     */
     public function testVarNotSet()
     {
         $default = 'foo';
@@ -34,6 +56,12 @@ class PMA_ifSetOr_test extends PHPUnit_Framework_TestCase
         $out = PMA_ifSetOr($in, $default);
         $this->assertEquals($out, $default);
     }
+
+    /**
+     * Test for PMA_ifSetOr
+     *
+     * @return void
+     */
     public function testVarNotSetNoDefault()
     {
         // $in is not set!
@@ -42,4 +70,3 @@ class PMA_ifSetOr_test extends PHPUnit_Framework_TestCase
     }
 
 }
-?>
